import 'package:cheminova/models/select_task_response.dart';
import 'package:cheminova/provider/select_task_provider.dart';
import 'package:flutter/material.dart';
import 'package:cheminova/screens/collect_kyc_screen.dart';
import 'package:cheminova/widgets/common_app_bar.dart';
import 'package:cheminova/widgets/common_drawer.dart';
import 'package:cheminova/widgets/common_background.dart';
import 'package:intl/intl.dart';
import 'package:provider/provider.dart';

class SelectTaskkycScreen extends StatefulWidget {
  const SelectTaskkycScreen({super.key});

  @override
  State<SelectTaskkycScreen> createState() => SelectTaskkycScreenState();
}

class SelectTaskkycScreenState extends State<SelectTaskkycScreen> {
  late SelectTaskProvider _selectTaskProvider;

  @override
  void initState() {
    _selectTaskProvider = SelectTaskProvider();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return ChangeNotifierProvider(
      create: (context) => _selectTaskProvider,
      child: CommonBackground(
        child: Scaffold(
          backgroundColor: Colors.transparent,
          appBar: CommonAppBar(
            title: const Text('Select Task'),
            backgroundColor: Colors.transparent,
            elevation: 0,
            actions: [
              IconButton(
                onPressed: () => Navigator.pop(context),
                icon: Image.asset('assets/Back_attendance.png'),
                padding: const EdgeInsets.only(right: 20),
              ),
            ],
          ),
          drawer: const CommonDrawer(),
          body: Consumer<SelectTaskProvider>(
            builder: (context, value, child) =>
            value.isLoading
                ? const Center(child: CircularProgressIndicator())
                : _buildTaskList(),
          ),
        ),
      ),
    );
  }

  Widget _buildTaskList() {
    return Consumer<SelectTaskProvider>(
      builder: (context, value, child) {
        if (value.tasksList.isEmpty) {
          return const Center(
            child: Text(
              'NO TASK',
              style: TextStyle(
                fontSize: 18,
                fontWeight: FontWeight.bold,
                color: Colors.black87,
              ),
            ),
          );
        }
        return ListView.builder(
          itemCount: value.tasksList.length,
          itemBuilder: (context, index) => _buildTaskCard(value.tasksList[index]),
        );
      },
    );
  }

  Widget _buildTaskCard(Tasks task) {
    return InkWell(
      onTap: () => Navigator.push(
        context,
        MaterialPageRoute(
          builder: (context) => CollectKycScreen(id: task.sId ?? ''),
        ),
      ),
      child: Card(
        margin: const EdgeInsets.symmetric(horizontal: 16, vertical: 8),
        color: Colors.white,
        shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(10)),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            ListTile(
              leading: const Icon(Icons.task, color: Colors.blueAccent),
              title: Text(
                task.task ?? '',
                style: const TextStyle(
                  color: Colors.black87,
                  fontWeight: FontWeight.w700,
                  fontSize: 16,
                  fontFamily: 'Anek',
                ),
              ),
              trailing: const Icon(Icons.arrow_forward_ios, color: Colors.black87),
            ),
            Padding(
              padding: const EdgeInsets.all(8.0),
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Text('Note: ${task.note}'),
                  if (task.taskDueDate != null)
                    Text(
                      'Date: ${task.taskDueDate == null ? '' : DateFormat('dd/MM/yyyy').format(DateTime.parse(task.taskDueDate ?? ''))}',
                    ),
                  Text('Priority: ${task.taskPriority}'),
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }
}

class TaskItem {
  final String title;
  final Widget screen;

  TaskItem({required this.title, required this.screen});
}

class KycTaskItem extends TaskItem {
  final String note;
  final String date;
  final String priority;

  KycTaskItem({
    required String title,
    required Widget screen,
    required this.note,
    required this.date,
    required this.priority,
  }) : super(title: title, screen: screen);
}